@@ -1,5 +1,5 @@
 /* GADMIN-BIND - An easy to use GTK+ frontend for the ISC BIND DNS Server.
- * Copyright (C) 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -753,8 +753,8 @@ void apply_domain_settings_button_clicked(struct w *widgets)
     G_CONST_RETURN gchar *domain_name = gtk_entry_get_text(GTK_ENTRY(widgets->domain_settings_entry[0]));
 
     /* FIXME: All matching A, AAAA and PTR records must be changed (if used) */
-    G_CONST_RETURN gchar *ipv4_network_address = gtk_entry_get_text(GTK_ENTRY(widgets->domain_settings_entry[1]));
-    G_CONST_RETURN gchar *ipv6_network_address = gtk_entry_get_text(GTK_ENTRY(widgets->domain_settings_entry[2]));
+//    G_CONST_RETURN gchar *ipv4_network_address = gtk_entry_get_text(GTK_ENTRY(widgets->domain_settings_entry[1]));
+//    G_CONST_RETURN gchar *ipv6_network_address = gtk_entry_get_text(GTK_ENTRY(widgets->domain_settings_entry[2]));
 
     G_CONST_RETURN gchar *admin_email = gtk_entry_get_text(GTK_ENTRY(widgets->domain_settings_entry[3]));
     G_CONST_RETURN gchar *domain_serial = gtk_entry_get_text(GTK_ENTRY(widgets->domain_settings_entry[4]));
